# AEGIS Epidemic Simulator

← Monitor
Tick: 0 Speed: 10 t/s

### Scenario Parameters

Agents Topology
Mean Degree BA edges (m) Rewire Prob Communities Intra Prob Inter Prob Initial Infected % Seed Strategy
Background Rate Recovery Ticks Max Ticks Random Seed

#### Technique Probabilities

Worm Propagation Memory Poisoning Role Hijacking Credential Extraction Shell Injection

### AEGIS Modules

Adoption Rate 0.90 Scanner
Pattern Matching Semantic Analysis Content Gate
Sensitivity 0.50 Confidence 0.80 Broker Identity Behavior Recovery

### Presets

Clean Infected Quarantined Recovered
0 entries

| Agent | Hash | Status | Cluster | Contagion
--- | --- | --- | --- | --- | ---

### Confusion Matrix

Detected
Not Det.
Present
0
0
Absent
0
0
Precision: - Recall: - F1: - FPR: -

### Event Log

Seed R: - Re: - Infections: 0 Detection Rate: - FPR: - MTTQ: - Clusters: -